--AH:ScriptId=9ce67334-03d8-436a-9314-79984b81cf8a;2822
IF OBJECT_ID('ParseNuGetVersion') IS NOT NULL DROP FUNCTION [ParseNuGetVersion]
GO

CREATE FUNCTION [ParseNuGetVersion]
(
	@Version_Text NVARCHAR(50)
)
RETURNS @ParsedVersion TABLE
(
	[Major] INT,
	[Minor] INT,
	[Patch] INT,
	[Build] INT,
	[Prerelease] NVARCHAR(40)
)
AS
BEGIN

	DECLARE @Version_Buffer NVARCHAR(50)
	SET @Version_Buffer = @Version_Text

	DECLARE @Prerelease NVARCHAR(40)

	DECLARE @Dash_Index INT
	SET @Dash_Index = CHARINDEX('-', @Version_Text)
	IF @Dash_Index > 0
	BEGIN
		SET @Prerelease = SUBSTRING(@Version_Buffer, @Dash_Index + 1, LEN(@Version_Buffer))
		SET @Version_Buffer = LEFT(@Version_Buffer, @Dash_Index - 1)
	END

	DECLARE @Version_Parts TABLE
	(
		[Index] INT NOT NULL,
		[Part] NVARCHAR(50) NOT NULL
	)

	INSERT INTO @Version_Parts
	(
		[Index],
		[Part]
	)
	SELECT [Value_Index],
	       [Value_Text]
	  FROM dbo.CsvToTable(@Version_Buffer, '.')

	DECLARE @Major_Text NVARCHAR(10)
	SET @Major_Text = (SELECT [Part] FROM @Version_Parts WHERE [Index] = 1)

	DECLARE @Minor_Text NVARCHAR(10)
	SET @Minor_Text = (SELECT [Part] FROM @Version_Parts WHERE [Index] = 2)

	DECLARE @Patch_Text NVARCHAR(10)
	SET @Patch_Text = (SELECT [Part] FROM @Version_Parts WHERE [Index] = 3)

	DECLARE @Build_Text NVARCHAR(10)
	SET @Build_Text = (SELECT [Part] FROM @Version_Parts WHERE [Index] = 4)

	INSERT INTO @ParsedVersion
	SELECT [Major] = CASE WHEN PATINDEX('%[^0-9]%', @Major_Text) > 0 THEN NULL ELSE CAST(@Major_Text AS INT) END,
	       [Minor] = CASE WHEN PATINDEX('%[^0-9]%', @Minor_Text) > 0 THEN NULL ELSE CAST(@Minor_Text AS INT) END,
		   [Patch] = CASE WHEN PATINDEX('%[^0-9]%', @Patch_Text) > 0 THEN NULL ELSE CAST(@Patch_Text AS INT) END,
		   [Build] = CASE WHEN PATINDEX('%[^0-9]%', @Build_Text) > 0 THEN NULL ELSE CAST(@Build_Text AS INT) END,
		   [Prerelease] = NULLIF(@Prerelease, '')

	RETURN

END